pub struct ChainedSessionsCtl {
sender: Sender<CscCommand>,
}Expand description
Keeps track of chained sessions
Create using Self::new. Cheaply cloneable.
Fields
sender: Sender<CscCommand>Implementations
Sourceimpl ChainedSessionsCtl
impl ChainedSessionsCtl
Sourcepub async fn create_session(&self) -> Result<Id>
pub async fn create_session(&self) -> Result<Id>
Creates a new chained session, returning its id::Id
Sourcepub async fn wait_for_result(
&self,
chained_session_id: Id,
) -> Result<YiviWaitForResultResp>
pub async fn wait_for_result( &self, chained_session_id: Id, ) -> Result<YiviWaitForResultResp>
Wait for the disclosure to arrive for the given chained session
Sourcepub async fn wait_for_next_session(
self,
chained_session_id: Id,
request_id: Id,
disclosure: JWT,
) -> Result<Option<ExtendedSessionRequest>>
pub async fn wait_for_next_session( self, chained_session_id: Id, request_id: Id, disclosure: JWT, ) -> Result<Option<ExtendedSessionRequest>>
Registers incoming disclosure and waits for the next session.
Returns None if the yivi session is to be ended normally, without starting a next
session.
Sourcepub async fn release_next_session(
&self,
chained_session_id: Id,
next_session_request: Option<ExtendedSessionRequest>,
stale_after: Option<u16>,
) -> Result<YiviReleaseNextSessionResp>
pub async fn release_next_session( &self, chained_session_id: Id, next_session_request: Option<ExtendedSessionRequest>, stale_after: Option<u16>, ) -> Result<YiviReleaseNextSessionResp>
Hands the next session request (if any) to the waiting yivi server
async fn send_command(&self, cmd: CscCommand) -> Result<()>
Sourcepub fn new(ctx: YiviCtx) -> Self
pub fn new(ctx: YiviCtx) -> Self
Creates a new ChainedSessionsCtl instance, and spawns a background task to drive it.
async fn drive(ctx: YiviCtx, receiver: Receiver<CscCommand>)